@@ -39,9 +39,6 @@ from pysnmp import debug
 
 import asyncio
 
-IS_PYTHON_344_PLUS = tuple(int(version) for version in platform.python_version_tuple()) >= (3, 4, 4)
-
-
 class DgramAsyncioProtocol(asyncio.DatagramProtocol, AbstractAsyncioTransport):
     """Base Asyncio datagram Transport, to be used with AsyncioDispatcher"""
     sockFamily = None
@@ -84,10 +81,7 @@ class DgramAsyncioProtocol(asyncio.DatagramProtocol, AbstractAsyncioTransport):
                 lambda: self, local_addr=iface, family=self.sockFamily
             )
             # Avoid deprecation warning for asyncio.async()
-            if IS_PYTHON_344_PLUS:
-              self._lport = asyncio.ensure_future(c)
-            else: # pragma: no cover
-              self._lport = getattr(asyncio, 'async')(c)
+            self._lport = asyncio.ensure_future(c)
 
         except Exception:
             raise error.CarrierError(';'.join(traceback.format_exception(*sys.exc_info())))
@@ -99,10 +93,7 @@ class DgramAsyncioProtocol(asyncio.DatagramProtocol, AbstractAsyncioTransport):
                 lambda: self, local_addr=iface, family=self.sockFamily
             )
             # Avoid deprecation warning for asyncio.async()
-            if IS_PYTHON_344_PLUS:
-              self._lport = asyncio.ensure_future(c)
-            else: # pragma: no cover
-              self._lport = getattr(asyncio, 'async')(c)
+            self._lport = asyncio.ensure_future(c)
         except Exception:
             raise error.CarrierError(';'.join(traceback.format_exception(*sys.exc_info())))
         return self
